@@ -35,20 +35,21 @@ sub make {
             'RCP-P2',   # The attempted recipient's preferences prevent messages from being delivered.
             'RCP-P3',   # The attempted recipient's privacy settings blocked the delivery.
         ],
+        'blocked' => [
+            'POL-P1',   # Your mail server's IP Address is listed on the Spamhaus PBL.
+            'POL-P2',   # Facebook will no longer accept mail from your mail server's IP Address.
+        ],
         'mesgtoobig' => [
             'MSG-P1',   # The message exceeds Facebook's maximum allowed size.
             'INT-P2',   # The message exceeds Facebook's maximum allowed size.
         ],
         'contenterror' => [
             'MSG-P2',   # The message contains an attachment type that Facebook does not accept.
-            'MSG-P3',   # The message contains multiple instances of a header field that can only be present once. Please see RFC 5322, section 3.6 for more information
+            'MSG-P3',   # The message contains multiple instances of a header field that can only be present once.
             'POL-P6',   # The message contains a url that has been blocked by Facebook.
             'POL-P7',   # The message does not comply with Facebook's abuse policies and will not be accepted.
         ],
         'securityerror' => [
-            'POL-P1',   # Your mail server's IP Address is listed on the Spamhaus PBL.
-            'POL-P2',   # Facebook will no longer accept mail from your mail server's IP Address.
-            'POL-P5',   # The message contains a virus.
             'POL-P7',   # The message does not comply with Facebook's Domain Authentication requirements.
         ],
         'notaccept' => [
@@ -67,17 +68,20 @@ sub make {
         ],
         'systemerror' => [
             'CON-T1',   # Facebook's mail server currently has too many connections open to allow another one.
+            'RCP-T1',   # The attempted recipient address is not currently available due to an internal system issue. This is a temporary condition.
         ],
         'toomanyconn' => [
+            'CON-T2',   # Your mail server currently has too many connections open to Facebook's mail servers.
             'CON-T3',   # Your mail server has opened too many new connections to Facebook's mail servers in a short period of time.
         ],
+        'virusdetected' => [
+            'POL-P5',   # The message contains a virus.
+        ],
         'suspend' => [
             'RCP-T4',   # The attempted recipient address is currently deactivated. The user may or may not reactivate it.
         ],
         'undefined' => [
-            'RCP-T1',   # The attempted recipient address is not currently available due to an internal system issue. This is a temporary condition.
             'MSG-T1',   # The number of recipients on the message exceeds Facebook's allowed maximum.
-            'CON-T2',   # Your mail server currently has too many connections open to Facebook's mail servers.
             'CON-T4',   # Your mail server has exceeded the maximum number of recipients for its current connection.
         ],
     };
@@ -226,7 +230,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2020 azumakuniyuki, All rights reserved.
+Copyright (C) 2014-2020,2022 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
