@@ -4,10 +4,6 @@ use feature ':5.10';
 use strict;
 use warnings;
 
-state $Indicators = __PACKAGE__->INDICATORS;
-state $ReBackbone = qr|^--- Original message follows[.]|m;
-state $StartingOf = { 'message' => ['Unable to deliver message to the following address'] };
-
 sub description { 'Unknown MTA #2' }
 sub make {
     # Detect an error from Unknown MTA #2
@@ -23,8 +19,12 @@ sub make {
     return undef unless index($mhead->{'from'}, 'MAILER-DAEMON@') > -1;
     return undef unless $mhead->{'subject'} =~ /\A(?>Delivery[ ]failure|fail(?:ure|ed)[ ]delivery)/;
 
+    state $indicators = __PACKAGE__->INDICATORS;
+    state $rebackbone = qr|^--- Original message follows[.]|m;
+    state $startingof = { 'message' => ['Unable to deliver message to the following address'] };
+
     my $dscontents = [__PACKAGE__->DELIVERYSTATUS];
-    my $emailsteak = Sisimai::RFC5322->fillet($mbody, $ReBackbone);
+    my $emailsteak = Sisimai::RFC5322->fillet($mbody, $rebackbone);
     my $readcursor = 0;     # (Integer) Points the current cursor position
     my $recipients = 0;     # (Integer) The number of 'Final-Recipient' header
     my $v = undef;
@@ -34,10 +34,10 @@ sub make {
         # to the previous line of the beginning of the original message.
         unless( $readcursor ) {
             # Beginning of the bounce message or message/delivery-status part
-            $readcursor |= $Indicators->{'deliverystatus'} if index($e, $StartingOf->{'message'}->[0]) == 0;
+            $readcursor |= $indicators->{'deliverystatus'} if index($e, $startingof->{'message'}->[0]) == 0;
             next;
         }
-        next unless $readcursor & $Indicators->{'deliverystatus'};
+        next unless $readcursor & $indicators->{'deliverystatus'};
         next unless length $e;
 
         # Message from example.com.
